==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VirtualHubRouteTableV2Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * VirtualHubRouteTableV2 Resource.
 * @property attachedConnections List of all connections attached to this route table v2.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property routes List of all routes.
 */
public data class VirtualHubRouteTableV2Args(
    public val attachedConnections: Output<List<String>>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val routes: Output<List<VirtualHubRouteV2Args>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args =
        com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args.builder()
            .attachedConnections(attachedConnections?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .routes(
                routes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualHubRouteTableV2Args].
 */
@PulumiTagMarker
public class VirtualHubRouteTableV2ArgsBuilder internal constructor() {
    private var attachedConnections: Output<List<String>>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var routes: Output<List<VirtualHubRouteV2Args>>? = null

    /**
     * @param value List of all connections attached to this route table v2.
     */
    @JvmName("csvlcsvedpipkfel")
    public suspend fun attachedConnections(`value`: Output<List<String>>) {
        this.attachedConnections = value
    }

    @JvmName("qpfwqxtgilithnkh")
    public suspend fun attachedConnections(vararg values: Output<String>) {
        this.attachedConnections = Output.all(values.asList())
    }

    /**
     * @param values List of all connections attached to this route table v2.
     */
    @JvmName("jtfnfyfgcydkitlg")
    public suspend fun attachedConnections(values: List<Output<String>>) {
        this.attachedConnections = Output.all(values)
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("ermlovulwaqyygvg")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("cxsuwabtjmefojlu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of all routes.
     */
    @JvmName("lnocjnedawtavojx")
    public suspend fun routes(`value`: Output<List<VirtualHubRouteV2Args>>) {
        this.routes = value
    }

    @JvmName("xgdnucwoolvkragi")
    public suspend fun routes(vararg values: Output<VirtualHubRouteV2Args>) {
        this.routes = Output.all(values.asList())
    }

    /**
     * @param values List of all routes.
     */
    @JvmName("xbcdkklvrqhwkpph")
    public suspend fun routes(values: List<Output<VirtualHubRouteV2Args>>) {
        this.routes = Output.all(values)
    }

    /**
     * @param value List of all connections attached to this route table v2.
     */
    @JvmName("vfwukdaeusnnslih")
    public suspend fun attachedConnections(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.attachedConnections = mapped
    }

    /**
     * @param values List of all connections attached to this route table v2.
     */
    @JvmName("neqkeqxrmnmbluxv")
    public suspend fun attachedConnections(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.attachedConnections = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("foeujlblxfyekrae")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("hqtxtormcltqlebh")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value List of all routes.
     */
    @JvmName("jnatfqewtxonpabh")
    public suspend fun routes(`value`: List<VirtualHubRouteV2Args>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    /**
     * @param argument List of all routes.
     */
    @JvmName("jumhxfnkatanjjsu")
    public suspend fun routes(argument: List<suspend VirtualHubRouteV2ArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualHubRouteV2ArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    /**
     * @param argument List of all routes.
     */
    @JvmName("hfwgdsolbanswnhf")
    public suspend fun routes(vararg argument: suspend VirtualHubRouteV2ArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            VirtualHubRouteV2ArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    /**
     * @param argument List of all routes.
     */
    @JvmName("xsckyobdkbwbufqm")
    public suspend fun routes(argument: suspend VirtualHubRouteV2ArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualHubRouteV2ArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    /**
     * @param values List of all routes.
     */
    @JvmName("puudtywroepfkpvo")
    public suspend fun routes(vararg values: VirtualHubRouteV2Args) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    internal fun build(): VirtualHubRouteTableV2Args = VirtualHubRouteTableV2Args(
        attachedConnections = attachedConnections,
        id = id,
        name = name,
        routes = routes,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VirtualHubRouteTableV2Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * VirtualHubRouteTableV2 Resource.
 * @property attachedConnections List of all connections attached to this route table v2.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property routes List of all routes.
 */
public data class VirtualHubRouteTableV2Args(
    public val attachedConnections: Output<List<String>>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val routes: Output<List<VirtualHubRouteV2Args>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args =
        com.pulumi.azurenative.network.inputs.VirtualHubRouteTableV2Args.builder()
            .attachedConnections(attachedConnections?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .routes(
                routes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualHubRouteTableV2Args].
 */
@PulumiTagMarker
public class VirtualHubRouteTableV2ArgsBuilder internal constructor() {
    private var attachedConnections: Output<List<String>>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var routes: Output<List<VirtualHubRouteV2Args>>? = null

    /**
     * @param value List of all connections attached to this route table v2.
     */
    @JvmName("oidcislrhtqceyxv")
    public suspend fun attachedConnections(`value`: Output<List<String>>) {
        this.attachedConnections = value
    }

    @JvmName("gepgfnyduffytgkl")
    public suspend fun attachedConnections(vararg values: Output<String>) {
        this.attachedConnections = Output.all(values.asList())
    }

    /**
     * @param values List of all connections attached to this route table v2.
     */
    @JvmName("uggubmctpokhdolh")
    public suspend fun attachedConnections(values: List<Output<String>>) {
        this.attachedConnections = Output.all(values)
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("iyvthfoiwtahpcfs")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("cphjipbadlexporp")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of all routes.
     */
    @JvmName("ggpcoimxllwknfti")
    public suspend fun routes(`value`: Output<List<VirtualHubRouteV2Args>>) {
        this.routes = value
    }

    @JvmName("vpebsrngtyykprbv")
    public suspend fun routes(vararg values: Output<VirtualHubRouteV2Args>) {
        this.routes = Output.all(values.asList())
    }

    /**
     * @param values List of all routes.
     */
    @JvmName("varhgqjcmfoudnjh")
    public suspend fun routes(values: List<Output<VirtualHubRouteV2Args>>) {
        this.routes = Output.all(values)
    }

    /**
     * @param value List of all connections attached to this route table v2.
     */
    @JvmName("inwwfnrgyafmowoj")
    public suspend fun attachedConnections(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.attachedConnections = mapped
    }

    /**
     * @param values List of all connections attached to this route table v2.
     */
    @JvmName("vowqmviupfbwysht")
    public suspend fun attachedConnections(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.attachedConnections = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("wfgbjganuiqbbmon")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("uxntydqbrqcqanex")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value List of all routes.
     */
    @JvmName("krtwcdgoypqbyojc")
    public suspend fun routes(`value`: List<VirtualHubRouteV2Args>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    /**
     * @param argument List of all routes.
     */
    @JvmName("sopvayjrsjgvjfaa")
    public suspend fun routes(argument: List<suspend VirtualHubRouteV2ArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualHubRouteV2ArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    /**
     * @param argument List of all routes.
     */
    @JvmName("nhvopilxedgshqrd")
    public suspend fun routes(vararg argument: suspend VirtualHubRouteV2ArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            VirtualHubRouteV2ArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    /**
     * @param argument List of all routes.
     */
    @JvmName("dgunxwclqgiaiuib")
    public suspend fun routes(argument: suspend VirtualHubRouteV2ArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualHubRouteV2ArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    /**
     * @param values List of all routes.
     */
    @JvmName("wmodgxqhyuvtocwo")
    public suspend fun routes(vararg values: VirtualHubRouteV2Args) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    internal fun build(): VirtualHubRouteTableV2Args = VirtualHubRouteTableV2Args(
        attachedConnections = attachedConnections,
        id = id,
        name = name,
        routes = routes,
    )
}
